@@ -42,7 +42,7 @@ class ModelifyController:
         config_file_path = os.path.join(self.model_folder_path, ModelifyFile.CONFIG.file_name)
 
         with open(config_file_path, "r") as yamlfile:
-            self.config = yaml.load(yamlfile, Loader=yaml.FullLoader)
+            self.config = yaml.load(yamlfile, Loader=yaml.Loader)
 
     @property
     def title(self):
